# @summary Installs nvidia's CUDA driver
#
# @param version
#   The version of CUDA to install.
#
# @param basrc_file_path
#   The path to the basrch file to update (uses concat).
#   If this parameter is set, will update the bashrc file with cuda environment variables.
#
class nvidia::cuda (
  String           $version          = '11-5',
  Optional[String] $bashrc_file_path = undef,
){

  case $::os['release']['full'] {
    '18.04' : {
      $repo_version = 'ubuntu1804'
    }
    '20.04', '21.04' , '21.10' : {
      $repo_version = 'ubuntu2004'
    }
    default : {
      fail("${::os::distro::release::full} unsupported")
    }
  }

  # gpg keys can be found here:
  # https://developer.download.nvidia.com/compute/cuda/repos/${DISTRO}/${ARCHITECTURE}/7fa2af80.pub 
  # download keys and run the following command to get the fingerprint
  # gpg --show-keys

  include apt

  apt::source{'cuda':
    comment  => 'A repository for nvidia cuda',
    key      => {
      id     => 'AE09FE4BBD223A84B2CCFCE3F60F4B3D7FA2AF80',
      server => "https://developer.download.nvidia.com/compute/cuda/repos/${repo_version}/x86_64/7fa2af80.pub",
    },
    location => "http://developer.download.nvidia.com/compute/cuda/repos/${repo_version}/x86_64/",
    repos    => '/',
    release  => '',
    include  => {
      src => false,
      deb => true,
    }
  }

  package{"cuda-toolkit-${version}":
    ensure  => latest,
    require => Apt::Source['cuda'],
  }

  package{'libcudnn8':
    ensure  => latest,
    require => Package["cuda-toolkit-${version}"],
  }

  if $bashrc_file_path {
    $version_major = split($version,'-')
    concat::fragment{'cuda_bashrc':
      target  => $bashrc_file_path,
      content => epp('nvidia/cuda_bashrc.epp',{
        version => $version_major[0],
      }),
      require => Package['libcudnn8'],
    }
  }
}
